@@ -196,6 +196,10 @@ class Git:
     def init(cls, cwd: PathOrStr):
         subprocess.check_output(["git", "init"], cwd=cwd)
 
+    @classmethod
+    def push(cls, cwd: PathOrStr):
+        exec("git push", cwd=cwd)
+
     @classmethod
     def pull(
         cls,
